# QuickDS

QuickDS is a library that contains a curated list of Input Formatting and Input Generating Functions that can be used to generate some commonly used Abstract data types without having to write any code from scratch. 
This library for was designed for the purposes of making competitive programming easy. 
Users can quickly convert Serialized Input formats into actual datastructures to quickly test their code in local IDE.

## Installation

```pip install QuickDS```

## License

This repository is Licensed under the MIT License.
See LICENSE for more details.